@@ -35,8 +35,9 @@
 
 #include "glade.h"
 #include "glade-catalog.h"
-#include "glade-widget-class.h"
+#include "glade-widget-adaptor.h"
 
+typedef void   (*GladeCatalogInitFunc) (void);
 
 struct _GladeCatalog
 {
@@ -52,18 +53,29 @@ struct _GladeCatalog
 				  * defaults to the library name)
 				  */
 	
+	gchar *book;             /* Devhelp search domain
+				  */
+
 	GList *widget_groups;    /* List of widget groups (palette)   */
-	GList *widget_classes;   /* List of widget classes (all)      */
+	GList *adaptors;         /* List of widget class adaptors (all)  */
 
 	GladeXmlContext *context;/* Xml context is stored after open
 				  * before classes are loaded         */
+	
+	GModule *module;
+	
+	gchar *init_function_name;/* Catalog's init function name */
+	GladeCatalogInitFunc init_function;
 };
 
 struct _GladeWidgetGroup
 {
 	gchar *name;             /* Group name                        */
-	gchar *title;            /* Group name on palette             */
-	GList *widget_classes;   /* List of classes in the palette    */
+	gchar *title;            /* Group name in the palette             */
+
+	gboolean expanded;       /* Whether group is expanded in the palette */
+
+	GList *adaptors;         /* List of class adaptors in the palette    */
 };
 
 static void            catalog_load         (GladeCatalog     *catalog);
@@ -74,12 +86,26 @@ static gboolean        catalog_load_classes (GladeCatalog     *catalog,
 static gboolean        catalog_load_group   (GladeCatalog     *catalog,
 					     GladeXmlNode     *group_node);
 
-void                   widget_group_free    (GladeWidgetGroup *group);
+static void            widget_group_free    (GladeWidgetGroup *group);
 
 /* List of catalog names successfully loaded.
  */
 static GList *loaded_catalogs = NULL;
 
+static gboolean
+catalog_get_function (GladeCatalog *catalog, 
+		      const gchar *symbol_name,
+		      gpointer *symbol_ptr)
+{
+	if (catalog->module == NULL)
+		catalog->module = glade_util_load_library (catalog->library);
+	
+	if (catalog->module)
+		return g_module_symbol (catalog->module, symbol_name, symbol_ptr);
+
+	return FALSE;
+}
+
 static GladeCatalog *
 catalog_open (const gchar *filename)
 {
@@ -88,8 +114,6 @@ catalog_open (const gchar *filename)
 	GladeXmlDoc     *doc;
 	GladeXmlNode    *root;
 
-	g_debug ("Loading catalog: %s\n", filename);
-
 	/* get the context & root node of the catalog file */
 	context = glade_xml_context_new_from_path (filename,
 						   NULL, 
@@ -130,8 +154,14 @@ catalog_open (const gchar *filename)
 		glade_xml_get_property_string (root, GLADE_TAG_DEPENDS);
 	catalog->domain =
 		glade_xml_get_property_string (root, GLADE_TAG_DOMAIN);
-
-	g_debug ("Successfully parsed catalog: %s\n", catalog->name);
+	catalog->book =
+		glade_xml_get_property_string (root, GLADE_TAG_BOOK);
+	catalog->init_function_name =
+		glade_xml_get_value_string (root, GLADE_TAG_INIT_FUNCTION);
+	
+	if (catalog->init_function_name)
+		catalog_get_function (catalog, catalog->init_function_name,
+				      (gpointer) &catalog->init_function);
 
 	return catalog;
 }
@@ -170,8 +200,6 @@ catalog_load (GladeCatalog *catalog)
 	catalog->widget_groups = g_list_reverse (catalog->widget_groups);
 	catalog->context =
 		(glade_xml_context_free (catalog->context), NULL);
-	
-	g_debug ("Successfully parsed catalog: %s\n", catalog->name);
 
 	return;
 }
@@ -194,7 +222,7 @@ catalog_sort (GList *catalogs)
 		catalog = l->data;
 		sort    = NULL;
 
-		/* itterate ascending through dependancy heirarchy */
+		/* itterate ascending through dependancy hierarchy */
 		while (catalog->dep_catalog) {
 			node = g_list_find_custom
 				(catalogs, catalog->dep_catalog,
@@ -235,19 +263,19 @@ catalog_load_classes (GladeCatalog *catalog, GladeXmlNode *widgets_node)
 	node = glade_xml_node_get_children (widgets_node);
 	for (; node; node = glade_xml_node_next (node)) 
 	{
-		const gchar      *node_name;
-		GladeWidgetClass *widget_class;
+		const gchar        *node_name;
+		GladeWidgetAdaptor *adaptor;
 
 		node_name = glade_xml_node_get_name (node);
 		if (strcmp (node_name, GLADE_TAG_GLADE_WIDGET_CLASS) != 0) 
 			continue;
 	
-		widget_class = glade_widget_class_new 
+		adaptor = glade_widget_adaptor_from_catalog 
 			(node, catalog->name, catalog->library, 
-			 catalog->domain ? catalog->domain : catalog->library);
+			 catalog->domain ? catalog->domain : catalog->library,
+			 catalog->book);
 
-		catalog->widget_classes = g_list_prepend (catalog->widget_classes,
-							  widget_class);
+		catalog->adaptors = g_list_prepend (catalog->adaptors, adaptor);
 	}
 
 	return TRUE;
@@ -263,6 +291,7 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 	
 	group->name = glade_xml_get_property_string (group_node, 
 						     GLADE_TAG_NAME);
+
 	if (!group->name) 
 	{ 
 		g_warning ("Required property 'name' not found in group node");
@@ -281,47 +310,56 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 		return FALSE;	
 	}
 
+	/* by default, group is expanded in palette  */
+	group->expanded = TRUE;
+
 	/* Translate it */
-	group->title = dgettext (catalog->domain ? catalog->domain : catalog->library, group->title);
+	group->title = dgettext (catalog->domain ? 
+				 catalog->domain : catalog->library, 
+				 group->title);
 
-	g_debug ("Loading widget group: %s\n", group->title);
-
-	group->widget_classes = NULL;
+	group->adaptors = NULL;
 
 	node = glade_xml_node_get_children (group_node);
 	for (; node; node = glade_xml_node_next (node)) 
 	{
-		const gchar      *node_name;
-		GladeWidgetClass *widget_class;
-		gchar            *name;
+		const gchar        *node_name;
+		GladeWidgetAdaptor *adaptor;
+		gchar              *name;
 
 		node_name = glade_xml_node_get_name (node);
 		
-		if (strcmp (node_name, GLADE_TAG_GLADE_WIDGET_CLASS_REF) != 0) 
-			continue;
-
-		name = glade_xml_get_property_string (node, GLADE_TAG_NAME);
-		if (!name) 
+		if (strcmp (node_name, GLADE_TAG_GLADE_WIDGET_CLASS_REF) == 0)
 		{
-			g_warning ("Couldn't find required property on %s",
-				   GLADE_TAG_GLADE_WIDGET_CLASS);
-			continue;
-		}
+			if ((name = 
+			     glade_xml_get_property_string (node, GLADE_TAG_NAME)) == NULL)
+			{
+				g_warning ("Couldn't find required property on %s",
+					   GLADE_TAG_GLADE_WIDGET_CLASS);
+				continue;
+			}
 
-		widget_class = glade_widget_class_get_by_name (name);
-		if (!widget_class) 
-		{
-			g_warning ("Tried to include undefined widget class '%s' in a widget group", name);
+			if ((adaptor = glade_widget_adaptor_get_by_name (name)) == NULL)
+			{
+				g_warning ("Tried to include undefined widget "
+					   "class '%s' in a widget group", name);
+				g_free (name);
+				continue;
+			}
 			g_free (name);
-			continue;
-		}
-		g_free (name);
 
-		group->widget_classes = g_list_prepend (group->widget_classes,
-							widget_class);
+			group->adaptors = g_list_prepend (group->adaptors, adaptor);
+
+		}
+		else if (strcmp (node_name, GLADE_TAG_DEFAULT_PALETTE_STATE) == 0)
+		{
+			group->expanded = 
+				glade_xml_get_property_boolean 
+				(node, GLADE_TAG_EXPANDED, group->expanded);
+		}
 	}
 
-	group->widget_classes = g_list_reverse (group->widget_classes);
+	group->adaptors = g_list_reverse (group->adaptors);
 
 	catalog->widget_groups = g_list_prepend (catalog->widget_groups,
 						 group);
@@ -329,7 +367,7 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 	return TRUE;
 }
 
-void
+static void
 widget_group_free (GladeWidgetGroup *group)
 {
 	g_return_if_fail (group != NULL);
@@ -338,14 +376,14 @@ widget_group_free (GladeWidgetGroup *group)
 	g_free (group->title);
 
 	/* The actual widget classes will be free elsewhere */
-	g_list_free (group->widget_classes);
+	g_list_free (group->adaptors);
 }
 	
 GList *
 glade_catalog_load_all (void)
 {
 	GDir         *dir;
-	GError       *error;
+	GError       *error = NULL;
 	const gchar  *filename;
 	GList        *catalogs, *l;
 	GladeCatalog *catalog;
@@ -383,8 +421,15 @@ glade_catalog_load_all (void)
 				   filename);
 	}
 
-	/* After sorting, load */
+	/* After sorting, execute init function and then load */
 	catalogs = catalog_sort (catalogs);
+	
+	for (l = catalogs; l; l = l->next)
+	{
+		catalog = l->data;
+		if (catalog->init_function) catalog->init_function ();
+	}
+	
 	for (l = catalogs; l; l = l->next)
 	{
 		catalog = l->data;
@@ -412,11 +457,11 @@ glade_catalog_get_widget_groups (GladeCatalog *catalog)
 }
 
 GList *
-glade_catalog_get_widget_classes (GladeCatalog *catalog)
+glade_catalog_get_adaptors (GladeCatalog *catalog)
 {
 	g_return_val_if_fail (catalog != NULL, NULL);
 
-	return catalog->widget_classes;	
+	return catalog->adaptors;	
 }
 
 void
@@ -428,11 +473,13 @@ glade_catalog_free (GladeCatalog *catalog)
 		return;
 
 	g_free (catalog->name);
+	if (catalog->book)
+		g_free (catalog->book);
 	
-	for (list = catalog->widget_classes; list; list = list->next)
-		glade_widget_class_free (GLADE_WIDGET_CLASS (list->data));
+	for (list = catalog->adaptors; list; list = list->next)
+		g_object_unref (list->data);
 	
-	g_list_free (catalog->widget_classes);
+	g_list_free (catalog->adaptors);
 
 	for (list = catalog->widget_groups; list; list = list->next) 
 		widget_group_free (GLADE_WIDGET_GROUP (list->data));
@@ -458,12 +505,20 @@ glade_widget_group_get_title (GladeWidgetGroup *group)
 	return group->title;
 }
 
+gboolean
+glade_widget_group_get_expanded (GladeWidgetGroup *group)
+{
+	g_return_val_if_fail (group != NULL, FALSE);
+
+	return group->expanded;
+}
+
 GList *
-glade_widget_group_get_widget_classes (GladeWidgetGroup *group)
+glade_widget_group_get_adaptors (GladeWidgetGroup *group)
 {
 	g_return_val_if_fail (group != NULL, NULL);
 
-	return group->widget_classes;
+	return group->adaptors;
 }
 
 gboolean
